@@ -16,7 +16,7 @@ Usage::
     session_client: SyntheticsClient = session.client("synthetics")
     ```
 """
-from mypy_boto3_synthetics.client import SyntheticsClient
+from .client import SyntheticsClient
 
 Client = SyntheticsClient
 
